# project-arrakis

python based particle tracking algorithms for CFD data

A highly parallelized set of Lagrangian particle tracking (LPT) algorithms based on Python to post-process steady and unsteady CFD data. An advanced programming interface (API) is developed for uncertainty quantification of optical velocimetry data.

# Installation:
Run the following command in the terminal to install the package:
```pip install project-arrakis```

### LPT Algorithms:

A sample code to start off is presented in main.py